@@ -521,3 +521,31 @@ class Bitpin:
         )
 
         return self._process_response(f_name, response, f_args)
+
+    def create_order(self, market: int, order_type: str, side: str, amount: float, price: float = None) -> t.Dict:
+
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        if order_type.lower() == 'limit' and price is None:
+            raise
+
+        url = '/v1/odr/orders/'
+
+        json_data = {
+            'market': market,
+            'mode': order_type,
+            'type': side,
+            'amount1': amount,
+            'price': price,
+            'price_limit': price,
+        }
+
+        response = self._request(
+            f_name,
+            'GET',
+            url,
+            auth=False,
+        )
+
+        return self._process_response(f_name, response, f_args)
